SizeConfig class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cardBorderRadius → const double
- fieldBorderRadius → const double
- horizontalCardPadding → const double
- iconSizeLarge → const double
- iconSizeMedium → const double
- iconSizeSmall → const double
- largeSpace → const double
- searchBorderRadius → const double
- sidePadding → const double
- smallSpace → const double
- space → const double
- verticalCardPadding → const double