CustomThemeHelper class

Constructors

CustomThemeHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDarkTheme(BuildContext context) → dynamic
setDefaultTheme(BuildContext context) → dynamic
setLightTheme(BuildContext context) → dynamic
toggleTheme(BuildContext context) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getColor(BuildContext context, {required String name}) → dynamic
getCurrentTheme(BuildContext context) String
isDarkMode(BuildContext context) bool